# frozen_string_literal: true

class Answer < ApplicationRecord
  has_paper_trail
  belongs_to :question
  belongs_to :survey_response
  has_many :answer_choices
  has_many :choices, through: :answer_choices
  scope :ordered, -> { includes(:question).order('questions.position') }
  accepts_nested_attributes_for :answer_choices, allow_destroy: true

  def text_answer
    return justification if question.text?

    array_answers = choices.order(:id).map do |c|
      placeholder = question.placeholder.blank? ? ', ' : ", #{question.placeholder} "
      if c.justifiable
        "#{c.value}#{placeholder}#{justification.capitalize}"
      else
        c.value
      end
    end
    array_answers.join(', ')
  end
end
